# New in 0.16.2 (2022-05-10)

## Changes

## Breaking changes

## Bug Fixes

-   Raise appropriate error when `backup_url` is not provided and file is missing on {meth}`~scvi.model.base.BaseModelClass.load` ([#1527]).
-   Pipe `loss_kwargs` properly in {class}`~scvi.train.AdversarialTrainingPlan`, and fix incorrectly piped kwargs in {class}`~scvi.model.TOTALVI` and {class}`~scvi.model.MULTIVI` ([#1532]).

## Contributors

-   [@jjhong922]
-   [@adamgayoso]

[#1527]: https://github.com/YosefLab/scvi-tools/pull/1527
[#1532]: https://github.com/YosefLab/scvi-tools/pull/1532
[@adamgayoso]: https://github.com/adamgayoso
[@jjhong922]: https://github.com/jjhong922
